summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authoradv <adv@uma.es>2011-03-08 09:02:09 +0000
committeradv <adv@uma.es>2011-03-08 09:02:09 +0000
commit7cc6687b7fcb82487a3953e8e0aaa67f60cb3e8e (patch)
treed6b9942c7fbf4dd29a0fc64fafcbb51be529e58b
parent9ef89207ae2380064ee9c3786b9a16855b5c089a (diff)
version1.0 openGnsysCopyClientFiles() ticket:313
git-svn-id: https://opengnsys.es/svn/branches/version1.0@1531 a21b9725-9963-47de-94b9-378ad31fedc9
-rwxr-xr-xinstaller/opengnsys_installer.sh8
1 files changed, 4 insertions, 4 deletions
diff --git a/installer/opengnsys_installer.sh b/installer/opengnsys_installer.sh
index 6f077109..3642747e 100755
--- a/installer/opengnsys_installer.sh
+++ b/installer/opengnsys_installer.sh
@@ -979,7 +979,7 @@ function copyInterfaceAdm ()
### Funciones instalacion cliente opengnsys
####################################################################
-function openGnsysClientCopyFiles()
+function openGnsysCopyClientFiles()
{
local hayErrores=0
@@ -1018,7 +1018,7 @@ function openGnsysOldClientCreate()
local hayErrores=0
#sustituido en la funcion openGnsysClientCopyFiles
#echoAndLog "${FUNCNAME}(): Copying OpenGnSys Client files."
# cp -ar $WORKDIR/opengnsys/client/shared/* $INSTALL_TARGET/client
# find $INSTALL_TARGET/client -name .svn -type d -exec rm -fr {} \; 2>/dev/null
@@ -1029,7 +1029,7 @@ function openGnsysOldClientCreate()
# errorAndLog "${FUNCNAME}(): error while copying engine files"
# hayErrores=1
#fi
# #sustituido en la funcion openGnsysClientCopyFiles
# Cargar Kernel, Initrd y paquetes udeb para la distribuciĆ³n del servidor (o por defecto).
OSCODENAME=$(lsb_release -cs 2>/dev/null)
@@ -1327,7 +1327,7 @@ popd
# Crear la estructura de los accesos al servidor desde el cliente (shared)
-openGnsysClientCopyFiles
+openGnsysCopyClientFiles
if [ $? -ne 0 ]; then
errorAndLog "Error creating client structure"
fi
@@ -1018,7 +1018,7 @@ function openGnsysOldClientCreate()
local hayErrores=0
-#sustituido en la funcion openGnsysClientCopyFiles
+#sustituido en la funcion openGnsysCopyClientFiles
#echoAndLog "${FUNCNAME}(): Copying OpenGnSys Client files."
# cp -ar $WORKDIR/opengnsys/client/shared/* $INSTALL_TARGET/client
@@ -1029,7 +1029,7 @@ function openGnsysOldClientCreate()
# hayErrores=1
#fi
-# #sustituido en la funcion openGnsysClientCopyFiles
+# #sustituido en la funcion openGnsysCopyClientFiles
# Cargar Kernel, Initrd y paquetes udeb para la distribuciĆ³n del servidor (o por defecto).
OSCODENAME=$(lsb_release -cs 2>/dev/null)